|project|
=========

.. include:: overview.rst

.. toctree-filt::
    :maxdepth: 1
    :numbered:

    introduction
    installation
    getting_started
    readers/index
    :geo2grid:compositors
    remapping
    writers/index
    utilscripts
    verification/index
    examples/index
    :geo2grid:data_access
    grids
    custom_grids
    image_processing_techniques

.. toctree-filt::
    :caption: Additional Details
    :maxdepth: 1
    :numbered:
    :excludebuilder: latex

    dev_guide/index
    :polar2grid:NEWS
    :geo2grid:NEWS_GEO2GRID
    enhancements
    :polar2grid:viirs_day_night_band
    custom_config

.. toctree-filt::
    :hidden:
    :excludebuilder: latex

    design_overview
    :polar2grid:misc_recipes
